@@ -121,16 +121,7 @@ open_request_logger (GPdfURIInput *in, const char *uri, gpointer user_data)
 static void
 set_window_icon_default (void)
 {
-	GdkPixbuf *pixbuf;
-
-	pixbuf = gdk_pixbuf_new_from_file (GNOMEICONDIR "/gnome-pdf.png", NULL);
-
-	if (pixbuf == NULL)
-		return;
-
-	gtk_window_set_default_icon (pixbuf);
-
-	g_object_unref (pixbuf);
+	gtk_window_set_default_icon_from_file (GNOMEICONDIR "/gnome-pdf.png", NULL);
 }
 
 int
