@@ -160,8 +160,10 @@ gpdf_print_job_prepare (GPdfPrintJob *pj)
 
 	config = gnome_print_job_get_config (pj->gnome_print_job);
 
+	width = height = -1.0;
+
 	/* width and height are returned in PS points :-) */
-	gnome_print_config_get_page_size (config, &width, &height);
+	/* gnome_print_config_get_page_size (config, &width, &height); */
 
 	globalParams->setPSPaperWidth ((int)width);
 	globalParams->setPSPaperHeight ((int)height);
