@@ -99,6 +99,7 @@ impl_bonobo_persist_file_load (PortableServer_Servant servant,
 	BonoboObject *object = bonobo_object_from_servant (servant);
 	GPdfPersistFile *pf = GPDF_PERSIST_FILE (object);
 	GPdfPersistFilePrivate *priv;
+	gchar *uri_scheme;
 	GnomeVFSResult vfs_result;
 	Object obj;
 	BaseStream *pdf_stream;
@@ -111,10 +112,16 @@ impl_bonobo_persist_file_load (PortableServer_Servant servant,
 	if (priv->pdf_doc || priv->vfs_handle || priv->uri)
 		gpdf_persist_file_unload (pf);
 
-	priv->uri = g_strdup (uri);
+	uri_scheme = gnome_vfs_get_uri_scheme (uri);
+	if (uri_scheme) // already looks like a URI
+		priv->uri = g_strdup (uri);
+	else
+		priv->uri = gnome_vfs_get_uri_from_local_path (uri);
+	
+	g_free (uri_scheme);
 
 	vfs_result = gnome_vfs_open (
-		&priv->vfs_handle, uri,
+		&priv->vfs_handle, priv->uri,
 		(GnomeVFSOpenMode) (GNOME_VFS_OPEN_READ |
 				    GNOME_VFS_OPEN_RANDOM));
 	if (vfs_result != GNOME_VFS_OK) {
